@@ -1,5 +1,10 @@
 var NAVTREEINDEX10 =
 {
+"group__API__SC__Hypervisor.html#ga96ec8fb00b7c1a93b7dd9e44deabbe77":[57,46,40],
+"group__API__SC__Hypervisor.html#ga9734466cc2ae6b8fcd280a602ac1cf40":[57,46,25],
+"group__API__SC__Hypervisor.html#ga9968686b96e842b384e2fd2495c8c7ab":[57,46,27],
+"group__API__SC__Hypervisor.html#gaa2299b4916c0e8b3ffe5db762d37d092":[57,46,52],
+"group__API__SC__Hypervisor.html#gaa768d65847bee6f26861217af9437ae2":[57,46,51],
 "group__API__SC__Hypervisor.html#gaafac498199c6441e2d45c9b4eac8dfe4":[57,46,7],
 "group__API__SC__Hypervisor.html#gab02cf89fff4e322e47bc96fb3b60b1ac":[57,46,44],
 "group__API__SC__Hypervisor.html#gab4e7dd4e4841b9e3db584b903043c3ad":[57,46,41],
@@ -244,10 +249,5 @@ var NAVTREEINDEX10 =
 "group__API__Task__Bundles.html#gadd37abde6806819967151a64146b19d6":[57,42,1],
 "group__API__Task__Bundles.html#gae8be4224d241ac2d30d9d573359e3280":[57,42,2],
 "group__API__Task__Bundles.html#gaf589986f5e69b7452ba90857d1931594":[57,42,6],
-"group__API__Task__Lists.html":[57,8],
-"group__API__Task__Lists.html#ad80731caf9d45900687caa7d5cc17cae":[57,8,0,1],
-"group__API__Task__Lists.html#af66edbac990d8e894796ca5d5dd45138":[57,8,0,0],
-"group__API__Task__Lists.html#ga02a847856d87dc7027c6f57e22a9e481":[57,8,12],
-"group__API__Task__Lists.html#ga1a9fbeedd7b9b0f77a18a8754a1bdeab":[57,8,13],
-"group__API__Task__Lists.html#ga367d90424e132d762e9a11eac2a822af":[57,8,10]
+"group__API__Task__Lists.html":[57,8]
 };
