@@ -1,5 +1,6 @@
 var NAVTREEINDEX2 =
 {
+"functions_l.html":[59,2,0,9],
 "functions_m.html":[59,2,0,10],
 "functions_n.html":[59,2,0,11],
 "functions_o.html":[59,2,0,12],
@@ -41,8 +42,8 @@ var NAVTREEINDEX2 =
 "globals_e.html":[60,1,0,1],
 "globals_enum.html":[60,1,4],
 "globals_eval.html":[60,1,5],
-"globals_func.html":[60,1,1,0],
 "globals_func.html":[60,1,1],
+"globals_func.html":[60,1,1,0],
 "globals_h.html":[60,1,0,2],
 "globals_s.html":[60,1,0,3],
 "globals_type.html":[60,1,3],
@@ -72,23 +73,25 @@ var NAVTREEINDEX2 =
 "group__API__Bubble.html#gadd5a0dfd0fca50c4f4db4af393687534":[57,25,0],
 "group__API__Bubble.html#gae34994c60e540d84c25212dccc3e7647":[57,25,4],
 "group__API__CUDA__Extensions.html":[57,10],
+"group__API__CUDA__Extensions.html#ga001e7af5e4205d61a0e9f174816dc260":[57,10,14],
 "group__API__CUDA__Extensions.html#ga08ef1dd9623d7adb87cede9e60d3e1dc":[57,10,6],
-"group__API__CUDA__Extensions.html#ga0b3c077a20a94757f3e6b7e36544ab97":[57,10,20],
+"group__API__CUDA__Extensions.html#ga0b3c077a20a94757f3e6b7e36544ab97":[57,10,22],
 "group__API__CUDA__Extensions.html#ga1f4ce467c5135681226d3764911d838c":[57,10,5],
 "group__API__CUDA__Extensions.html#ga20c5b69812878a57e22f4f3c5cc8f56f":[57,10,9],
 "group__API__CUDA__Extensions.html#ga305c371567096cedd87290bf68123ced":[57,10,3],
-"group__API__CUDA__Extensions.html#ga36e0141d9f28894cbb0c3235afc32ed1":[57,10,16],
+"group__API__CUDA__Extensions.html#ga36e0141d9f28894cbb0c3235afc32ed1":[57,10,17],
 "group__API__CUDA__Extensions.html#ga384db70769609ec68fae5a0105821299":[57,10,0],
 "group__API__CUDA__Extensions.html#ga3b170653608d3381b660afba63be39da":[57,10,12],
-"group__API__CUDA__Extensions.html#ga3cd8378588620422bc6c3246016ffcd8":[57,10,19],
+"group__API__CUDA__Extensions.html#ga3cd8378588620422bc6c3246016ffcd8":[57,10,20],
 "group__API__CUDA__Extensions.html#ga4c17ac2833d1294eb95d53a0fea8e6d2":[57,10,10],
 "group__API__CUDA__Extensions.html#ga5979aad48297e9f7263a06cc09f93593":[57,10,13],
-"group__API__CUDA__Extensions.html#ga60f4393ac61f22cafc9b13386274acba":[57,10,14],
+"group__API__CUDA__Extensions.html#ga60f4393ac61f22cafc9b13386274acba":[57,10,15],
 "group__API__CUDA__Extensions.html#ga71b71760c8b71cb6c3f0dc7495c84036":[57,10,8],
-"group__API__CUDA__Extensions.html#ga91a1f8b244999a0138d41df182b71846":[57,10,21],
-"group__API__CUDA__Extensions.html#ga97300f073573da28193c95d1379bf675":[57,10,18],
-"group__API__CUDA__Extensions.html#ga9f70358bd39f2228d7b0558702306d96":[57,10,15],
-"group__API__CUDA__Extensions.html#gab4e2ca2177108cd48c4b478078e85599":[57,10,17],
+"group__API__CUDA__Extensions.html#ga91a1f8b244999a0138d41df182b71846":[57,10,23],
+"group__API__CUDA__Extensions.html#ga97300f073573da28193c95d1379bf675":[57,10,19],
+"group__API__CUDA__Extensions.html#ga9f70358bd39f2228d7b0558702306d96":[57,10,16],
+"group__API__CUDA__Extensions.html#gab4e2ca2177108cd48c4b478078e85599":[57,10,18],
+"group__API__CUDA__Extensions.html#gabeab049aae5ab9950e688e5f04af7389":[57,10,21],
 "group__API__CUDA__Extensions.html#gad7d80d054bd2b9570e1d7e24442e19c0":[57,10,7],
 "group__API__CUDA__Extensions.html#gade384fd8f73cd4e4ab7768d90aff82b8":[57,10,1],
 "group__API__CUDA__Extensions.html#gae2a0ce53013a0c3d7bafaf0ec000cdd5":[57,10,2],
@@ -246,8 +249,5 @@ var NAVTREEINDEX2 =
 "group__API__Codelet__And__Tasks.html#ga783564eb626b105c5d8677beb028e67d":[57,2,78],
 "group__API__Codelet__And__Tasks.html#ga7c0f143c18956f4f6e74b2c379641f2e":[57,2,92],
 "group__API__Codelet__And__Tasks.html#ga7d5977bc7532b4b357ea8b1017b5aaca":[57,2,4],
-"group__API__Codelet__And__Tasks.html#ga7f931b9a69bb5dac48a9f8f904cd333e":[57,2,72],
-"group__API__Codelet__And__Tasks.html#ga829d31913f4b0890192d4924bd264f88":[57,2,35],
-"group__API__Codelet__And__Tasks.html#ga82b2ad7adb9e1c70d4c901a89be88d5d":[57,2,38],
-"group__API__Codelet__And__Tasks.html#ga82daae91cd3e4b86f77c413309b23c3d":[57,2,44]
+"group__API__Codelet__And__Tasks.html#ga7f931b9a69bb5dac48a9f8f904cd333e":[57,2,72]
 };
