@@ -1,5 +1,8 @@
 var NAVTREEINDEX4 =
 {
+"group__API__Data__Interfaces.html#ga3a3cf303a3e3be144aab7abdf587c900":[57,5,66],
+"group__API__Data__Interfaces.html#ga3aa3b2a467688f95fe6dd3355112dfc6":[57,5,188],
+"group__API__Data__Interfaces.html#ga3bb8d6c4169e578b219849148eece329":[57,5,43],
 "group__API__Data__Interfaces.html#ga3ef8a3c5b91f3d3b048a4e5f51a4c4c0":[57,5,47],
 "group__API__Data__Interfaces.html#ga3f0c5626c9d5f7addb417834d6be7861":[57,5,48],
 "group__API__Data__Interfaces.html#ga40384636cdeec2bdeeccf5a50a081c3b":[57,5,170],
@@ -246,8 +249,5 @@ var NAVTREEINDEX4 =
 "group__API__Data__Management.html#gae53e7b21c7426c9845a1046cfe5becce":[57,4,44],
 "group__API__Data__Management.html#gae5f926615eaa6e318ee0fc4ac0be9e3e":[57,4,38],
 "group__API__Data__Management.html#gae6eb535cf9bf46a7ef9ad2d845c675a2":[57,4,19],
-"group__API__Data__Management.html#gaedc8031c1b437d35232cd1700d83d472":[57,4,18],
-"group__API__Data__Management.html#gaef7203edaf1725977dffac23296ede4e":[57,4,47],
-"group__API__Data__Management.html#gaf2811b5c7d3570edf483ca1ece4bf4a0":[57,4,62],
-"group__API__Data__Management.html#gaf385e328d71dc2e202b17ec26f229414":[57,4,0]
+"group__API__Data__Management.html#gaedc8031c1b437d35232cd1700d83d472":[57,4,18]
 };
