@@ -1,5 +1,8 @@
 var NAVTREEINDEX5 =
 {
+"group__API__Data__Management.html#gaef7203edaf1725977dffac23296ede4e":[57,4,47],
+"group__API__Data__Management.html#gaf2811b5c7d3570edf483ca1ece4bf4a0":[57,4,62],
+"group__API__Data__Management.html#gaf385e328d71dc2e202b17ec26f229414":[57,4,0],
 "group__API__Data__Management.html#gaf971c53b3fa3d3746a8ae1f5291c7c4f":[57,4,57],
 "group__API__Data__Management.html#gafd48044a523ed5a4e11598596096dc52":[57,4,24],
 "group__API__Data__Management.html#gafd4b4f7f9f0a26f65a1e149525a09bfd":[57,4,42],
@@ -129,6 +132,7 @@ var NAVTREEINDEX5 =
 "group__API__Explicit__Dependencies.html":[57,7],
 "group__API__Explicit__Dependencies.html#ga19e120568fbd21fcac59b93ff324c45f":[57,7,4],
 "group__API__Explicit__Dependencies.html#ga1a93d3d46ea5ade29a3a3ea76b6eb90d":[57,7,8],
+"group__API__Explicit__Dependencies.html#ga2425f146494ef50105f99325f4120522":[57,7,18],
 "group__API__Explicit__Dependencies.html#ga2ab771900cf19e039ade46594dbc5fce":[57,7,3],
 "group__API__Explicit__Dependencies.html#ga53dc7bff09b441ee6a200cae99ca2cb8":[57,7,5],
 "group__API__Explicit__Dependencies.html#ga6d09446c8849f42edeced84c558e6a49":[57,7,17],
@@ -167,6 +171,7 @@ var NAVTREEINDEX5 =
 "group__API__FxT__Support.html#ad989ef1acebea5296285ba1543b9b8d3":[57,31,2,2],
 "group__API__FxT__Support.html#ae8825a6b5c62dd05bdc8508c9f0bf09c":[57,31,1,0],
 "group__API__FxT__Support.html#ae8b5695146698ba1d5aef8c9237b5272":[57,31,2,3],
+"group__API__FxT__Support.html#ga044878f9b946fd4c265ba6e725e2468c":[57,31,9],
 "group__API__FxT__Support.html#ga2e55ad671e94b6161755717b1c8b44c1":[57,31,7],
 "group__API__FxT__Support.html#ga52a3e1a95689315f0b789a3325ec2a90":[57,31,5],
 "group__API__FxT__Support.html#ga5793bf5c8fc0bedf76d18a5fa38593df":[57,31,4],
@@ -244,10 +249,5 @@ var NAVTREEINDEX5 =
 "group__API__Initialization__and__Termination.html#ae11cad1ceafab919d348de1f00b044d1":[57,0,0,46],
 "group__API__Initialization__and__Termination.html#ae34c59d8118504e53af4ba88b4254678":[57,0,0,42],
 "group__API__Initialization__and__Termination.html#ae439173bb5082ce8d6960d06c2f8e1d3":[57,0,0,45],
-"group__API__Initialization__and__Termination.html#ae728f399a0494ee9816483ab321b84d9":[57,0,0,12],
-"group__API__Initialization__and__Termination.html#aee75e823857e667c95edf346669b34ed":[57,0,0,18],
-"group__API__Initialization__and__Termination.html#af482c3dac3ed6d28ee51e72c9ad636e1":[57,0,0,17],
-"group__API__Initialization__and__Termination.html#af4d7aba8f400e06ffd8847c7f12e21e7":[57,0,0,8],
-"group__API__Initialization__and__Termination.html#af4da5685fda97febf35c7f02faee66e4":[57,0,0,34],
-"group__API__Initialization__and__Termination.html#aff1ae12be0c8b2366e8ecd0d980af806":[57,0,0,41]
+"group__API__Initialization__and__Termination.html#ae728f399a0494ee9816483ab321b84d9":[57,0,0,12]
 };
