@@ -1,7 +1,12 @@
 var NAVTREEINDEX12 =
 {
-"interfacefstarpu__mod_1_1fstarpu__task__finished.html":[7,0,0,239],
+"interfacefstarpu__mod_1_1fstarpu__task__dup.html":[6,0,0,236],
+"interfacefstarpu__mod_1_1fstarpu__task__end__dep__add.html":[7,0,0,237],
+"interfacefstarpu__mod_1_1fstarpu__task__end__dep__add.html":[6,0,0,237],
+"interfacefstarpu__mod_1_1fstarpu__task__end__dep__release.html":[6,0,0,238],
+"interfacefstarpu__mod_1_1fstarpu__task__end__dep__release.html":[7,0,0,238],
 "interfacefstarpu__mod_1_1fstarpu__task__finished.html":[6,0,0,239],
+"interfacefstarpu__mod_1_1fstarpu__task__finished.html":[7,0,0,239],
 "interfacefstarpu__mod_1_1fstarpu__task__get__current.html":[7,0,0,240],
 "interfacefstarpu__mod_1_1fstarpu__task__get__current.html":[6,0,0,240],
 "interfacefstarpu__mod_1_1fstarpu__task__get__implementation.html":[7,0,0,241],
@@ -12,24 +17,24 @@ var NAVTREEINDEX12 =
 "interfacefstarpu__mod_1_1fstarpu__task__insert.html":[6,0,0,243],
 "interfacefstarpu__mod_1_1fstarpu__task__nready.html":[7,0,0,244],
 "interfacefstarpu__mod_1_1fstarpu__task__nready.html":[6,0,0,244],
-"interfacefstarpu__mod_1_1fstarpu__task__nsubmitted.html":[7,0,0,245],
 "interfacefstarpu__mod_1_1fstarpu__task__nsubmitted.html":[6,0,0,245],
-"interfacefstarpu__mod_1_1fstarpu__task__set__destroy.html":[7,0,0,246],
+"interfacefstarpu__mod_1_1fstarpu__task__nsubmitted.html":[7,0,0,245],
 "interfacefstarpu__mod_1_1fstarpu__task__set__destroy.html":[6,0,0,246],
-"interfacefstarpu__mod_1_1fstarpu__task__set__implementation.html":[7,0,0,247],
+"interfacefstarpu__mod_1_1fstarpu__task__set__destroy.html":[7,0,0,246],
 "interfacefstarpu__mod_1_1fstarpu__task__set__implementation.html":[6,0,0,247],
-"interfacefstarpu__mod_1_1fstarpu__task__submit.html":[7,0,0,248],
+"interfacefstarpu__mod_1_1fstarpu__task__set__implementation.html":[7,0,0,247],
 "interfacefstarpu__mod_1_1fstarpu__task__submit.html":[6,0,0,248],
-"interfacefstarpu__mod_1_1fstarpu__task__submit__to__ctx.html":[7,0,0,249],
+"interfacefstarpu__mod_1_1fstarpu__task__submit.html":[7,0,0,248],
 "interfacefstarpu__mod_1_1fstarpu__task__submit__to__ctx.html":[6,0,0,249],
+"interfacefstarpu__mod_1_1fstarpu__task__submit__to__ctx.html":[7,0,0,249],
 "interfacefstarpu__mod_1_1fstarpu__task__wait.html":[7,0,0,250],
 "interfacefstarpu__mod_1_1fstarpu__task__wait.html":[6,0,0,250],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__array.html":[7,0,0,251],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__array.html":[6,0,0,251],
-"interfacefstarpu__mod_1_1fstarpu__task__wait__for__all.html":[6,0,0,252],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__all.html":[7,0,0,252],
-"interfacefstarpu__mod_1_1fstarpu__task__wait__for__all__in__ctx.html":[6,0,0,253],
+"interfacefstarpu__mod_1_1fstarpu__task__wait__for__all.html":[6,0,0,252],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__all__in__ctx.html":[7,0,0,253],
+"interfacefstarpu__mod_1_1fstarpu__task__wait__for__all__in__ctx.html":[6,0,0,253],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted.html":[6,0,0,254],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted.html":[7,0,0,254],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted__in__ctx.html":[6,0,0,255],
@@ -40,12 +45,12 @@ var NAVTREEINDEX12 =
 "interfacefstarpu__mod_1_1fstarpu__tensor__data__register.html":[7,0,0,257],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ldt.html":[6,0,0,258],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ldt.html":[7,0,0,258],
-"interfacefstarpu__mod_1_1fstarpu__tensor__get__ldy.html":[6,0,0,259],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ldy.html":[7,0,0,259],
-"interfacefstarpu__mod_1_1fstarpu__tensor__get__ldz.html":[7,0,0,260],
+"interfacefstarpu__mod_1_1fstarpu__tensor__get__ldy.html":[6,0,0,259],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ldz.html":[6,0,0,260],
-"interfacefstarpu__mod_1_1fstarpu__tensor__get__nt.html":[6,0,0,261],
+"interfacefstarpu__mod_1_1fstarpu__tensor__get__ldz.html":[7,0,0,260],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__nt.html":[7,0,0,261],
+"interfacefstarpu__mod_1_1fstarpu__tensor__get__nt.html":[6,0,0,261],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__nx.html":[7,0,0,262],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__nx.html":[6,0,0,262],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ny.html":[7,0,0,263],
@@ -54,66 +59,66 @@ var NAVTREEINDEX12 =
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__nz.html":[6,0,0,264],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ptr.html":[7,0,0,265],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ptr.html":[6,0,0,265],
-"interfacefstarpu__mod_1_1fstarpu__tensor__ptr__register.html":[7,0,0,266],
 "interfacefstarpu__mod_1_1fstarpu__tensor__ptr__register.html":[6,0,0,266],
-"interfacefstarpu__mod_1_1fstarpu__timing__now.html":[7,0,0,267],
+"interfacefstarpu__mod_1_1fstarpu__tensor__ptr__register.html":[7,0,0,266],
 "interfacefstarpu__mod_1_1fstarpu__timing__now.html":[6,0,0,267],
-"interfacefstarpu__mod_1_1fstarpu__topology__print.html":[6,0,0,268],
+"interfacefstarpu__mod_1_1fstarpu__timing__now.html":[7,0,0,267],
 "interfacefstarpu__mod_1_1fstarpu__topology__print.html":[7,0,0,268],
-"interfacefstarpu__mod_1_1fstarpu__trace__user__event.html":[6,0,0,269],
+"interfacefstarpu__mod_1_1fstarpu__topology__print.html":[6,0,0,268],
 "interfacefstarpu__mod_1_1fstarpu__trace__user__event.html":[7,0,0,269],
+"interfacefstarpu__mod_1_1fstarpu__trace__user__event.html":[6,0,0,269],
 "interfacefstarpu__mod_1_1fstarpu__unpack__arg.html":[6,0,0,270],
 "interfacefstarpu__mod_1_1fstarpu__unpack__arg.html":[7,0,0,270],
-"interfacefstarpu__mod_1_1fstarpu__usleep.html":[7,0,0,271],
 "interfacefstarpu__mod_1_1fstarpu__usleep.html":[6,0,0,271],
+"interfacefstarpu__mod_1_1fstarpu__usleep.html":[7,0,0,271],
 "interfacefstarpu__mod_1_1fstarpu__variable__data__register.html":[6,0,0,272],
 "interfacefstarpu__mod_1_1fstarpu__variable__data__register.html":[7,0,0,272],
-"interfacefstarpu__mod_1_1fstarpu__variable__get__ptr.html":[7,0,0,273],
 "interfacefstarpu__mod_1_1fstarpu__variable__get__ptr.html":[6,0,0,273],
-"interfacefstarpu__mod_1_1fstarpu__variable__ptr__register.html":[7,0,0,274],
+"interfacefstarpu__mod_1_1fstarpu__variable__get__ptr.html":[7,0,0,273],
 "interfacefstarpu__mod_1_1fstarpu__variable__ptr__register.html":[6,0,0,274],
-"interfacefstarpu__mod_1_1fstarpu__vector__data__register.html":[6,0,0,275],
+"interfacefstarpu__mod_1_1fstarpu__variable__ptr__register.html":[7,0,0,274],
 "interfacefstarpu__mod_1_1fstarpu__vector__data__register.html":[7,0,0,275],
-"interfacefstarpu__mod_1_1fstarpu__vector__divide__in__2.html":[7,0,0,276],
+"interfacefstarpu__mod_1_1fstarpu__vector__data__register.html":[6,0,0,275],
 "interfacefstarpu__mod_1_1fstarpu__vector__divide__in__2.html":[6,0,0,276],
+"interfacefstarpu__mod_1_1fstarpu__vector__divide__in__2.html":[7,0,0,276],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__block.html":[6,0,0,277],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__block.html":[7,0,0,277],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__block__shadow.html":[6,0,0,278],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__block__shadow.html":[7,0,0,278],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__list.html":[6,0,0,279],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__list.html":[7,0,0,279],
-"interfacefstarpu__mod_1_1fstarpu__vector__filter__list__long.html":[6,0,0,280],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__list__long.html":[7,0,0,280],
+"interfacefstarpu__mod_1_1fstarpu__vector__filter__list__long.html":[6,0,0,280],
 "interfacefstarpu__mod_1_1fstarpu__vector__get__nx.html":[6,0,0,281],
 "interfacefstarpu__mod_1_1fstarpu__vector__get__nx.html":[7,0,0,281],
 "interfacefstarpu__mod_1_1fstarpu__vector__get__ptr.html":[6,0,0,282],
 "interfacefstarpu__mod_1_1fstarpu__vector__get__ptr.html":[7,0,0,282],
-"interfacefstarpu__mod_1_1fstarpu__vector__ptr__register.html":[7,0,0,283],
 "interfacefstarpu__mod_1_1fstarpu__vector__ptr__register.html":[6,0,0,283],
+"interfacefstarpu__mod_1_1fstarpu__vector__ptr__register.html":[7,0,0,283],
 "interfacefstarpu__mod_1_1fstarpu__void__data__register.html":[6,0,0,284],
 "interfacefstarpu__mod_1_1fstarpu__void__data__register.html":[7,0,0,284],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__bindid.html":[6,0,0,285],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__bindid.html":[7,0,0,285],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__by__devid.html":[6,0,0,286],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__by__devid.html":[7,0,0,286],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__by__devid.html":[6,0,0,286],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__by__type.html":[6,0,0,287],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__by__type.html":[7,0,0,287],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__count.html":[6,0,0,288],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__count.html":[7,0,0,288],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__count.html":[6,0,0,288],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__count__by__type.html":[7,0,0,289],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__count__by__type.html":[6,0,0,289],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__devid.html":[6,0,0,290],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__devid.html":[7,0,0,290],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__id.html":[6,0,0,291],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__devid.html":[6,0,0,290],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__id.html":[7,0,0,291],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__ids__by__type.html":[6,0,0,292],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__id.html":[6,0,0,291],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__ids__by__type.html":[7,0,0,292],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__memory__node.html":[7,0,0,293],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__ids__by__type.html":[6,0,0,292],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__memory__node.html":[6,0,0,293],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__name.html":[6,0,0,294],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__memory__node.html":[7,0,0,293],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__name.html":[7,0,0,294],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__type.html":[6,0,0,295],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__name.html":[6,0,0,294],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__type.html":[7,0,0,295],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__type.html":[6,0,0,295],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__type__as__string.html":[7,0,0,296],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__type__as__string.html":[6,0,0,296],
 "interfacefstarpu__mod_1_1fstarpu__worker__is__blocked.html":[7,0,0,297],
@@ -244,10 +249,5 @@ var NAVTREEINDEX12 =
 "sc__hypervisor__monitoring_8h.html#a7ed3efcd3b7e2886f5610e5f5920eb99":[8,0,3,0,3,0,1],
 "sc__hypervisor__monitoring_8h.html#a8923658556a212b0ed82f2138a4c5850":[8,0,3,0,3,0,7],
 "sc__hypervisor__monitoring_8h.html#aa72bfdedf5238e9faaee87f48d72bebe":[8,0,3,0,3,0,20],
-"sc__hypervisor__monitoring_8h.html#ab35accf0d5a3a49c1ab43799aad115bb":[8,0,3,0,3,0,0],
-"sc__hypervisor__monitoring_8h.html#aba3d21edf846f13f3d41405ab7d99016":[8,0,3,0,3,0,21],
-"sc__hypervisor__monitoring_8h.html#abe9c30e847ed5dab431ffb1e753b4829":[8,0,3,0,3,0,15],
-"sc__hypervisor__monitoring_8h.html#abf552a3af2c6928c9f4e0dd6e845c7e0":[8,0,3,0,3,0,26],
-"sc__hypervisor__monitoring_8h.html#acd3f606a760909b7b7262b2927c537b3":[8,0,3,0,3,0,18],
-"sc__hypervisor__monitoring_8h.html#adfb3d97bbdc15b0f9acee62ab4ae6350":[8,0,3,0,3,0,8]
+"sc__hypervisor__monitoring_8h.html#ab35accf0d5a3a49c1ab43799aad115bb":[8,0,3,0,3,0,0]
 };
