@@ -1,5 +1,7 @@
 var NAVTREEINDEX3 =
 {
+"group__API__Data__Management.html#ga586146498466b60d6b81145dfaeb8948":[5,8,11],
+"group__API__Data__Management.html#ga5b95764e9545fc367cb995950e82f449":[5,8,29],
 "group__API__Data__Management.html#ga5fd09305716ce9d3a5a9fd2df6bc7792":[5,8,60],
 "group__API__Data__Management.html#ga690e27502b042cbc6969c5f3c5771a84":[5,8,25],
 "group__API__Data__Management.html#ga6e0e15426e75b43f7b44e3f3a38c01f1":[5,8,51],
@@ -170,6 +172,7 @@ var NAVTREEINDEX3 =
 "group__API__Explicit__Dependencies.html":[5,11],
 "group__API__Explicit__Dependencies.html#ga19e120568fbd21fcac59b93ff324c45f":[5,11,4],
 "group__API__Explicit__Dependencies.html#ga1a93d3d46ea5ade29a3a3ea76b6eb90d":[5,11,8],
+"group__API__Explicit__Dependencies.html#ga2425f146494ef50105f99325f4120522":[5,11,18],
 "group__API__Explicit__Dependencies.html#ga2ab771900cf19e039ade46594dbc5fce":[5,11,3],
 "group__API__Explicit__Dependencies.html#ga53dc7bff09b441ee6a200cae99ca2cb8":[5,11,5],
 "group__API__Explicit__Dependencies.html#ga6d09446c8849f42edeced84c558e6a49":[5,11,17],
@@ -208,6 +211,7 @@ var NAVTREEINDEX3 =
 "group__API__FxT__Support.html#ad989ef1acebea5296285ba1543b9b8d3":[5,34,2,2],
 "group__API__FxT__Support.html#ae8825a6b5c62dd05bdc8508c9f0bf09c":[5,34,1,0],
 "group__API__FxT__Support.html#ae8b5695146698ba1d5aef8c9237b5272":[5,34,2,3],
+"group__API__FxT__Support.html#ga044878f9b946fd4c265ba6e725e2468c":[5,34,9],
 "group__API__FxT__Support.html#ga2e55ad671e94b6161755717b1c8b44c1":[5,34,7],
 "group__API__FxT__Support.html#ga52a3e1a95689315f0b789a3325ec2a90":[5,34,5],
 "group__API__FxT__Support.html#ga5793bf5c8fc0bedf76d18a5fa38593df":[5,34,4],
@@ -245,9 +249,5 @@ var NAVTREEINDEX3 =
 "group__API__Initialization__and__Termination.html#a0a5291c6ff740ea7572f0e3d1b27bab2":[5,4,0,49],
 "group__API__Initialization__and__Termination.html#a0e2c1735e5422a33c3308b91969f08e3":[5,4,0,4],
 "group__API__Initialization__and__Termination.html#a1b93eddac8db0598b67d4e8324277abe":[5,4,0,36],
-"group__API__Initialization__and__Termination.html#a1fc825906ff041878bc3a05ce9681e9c":[5,4,0,30],
-"group__API__Initialization__and__Termination.html#a2275c89ee0aded13cc8836a0c5ef0188":[5,4,0,15],
-"group__API__Initialization__and__Termination.html#a27718585874f9012e9955ba308e2cd8f":[5,4,0,16],
-"group__API__Initialization__and__Termination.html#a290f151da116c90c48a1885dbba9c072":[5,4,0,32],
-"group__API__Initialization__and__Termination.html#a29b3ff0d1afa9e24a7edbb0765cea487":[5,4,0,31]
+"group__API__Initialization__and__Termination.html#a1fc825906ff041878bc3a05ce9681e9c":[5,4,0,30]
 };
