@@ -1,5 +1,9 @@
 var NAVTREEINDEX7 =
 {
+"group__API__Perf__Monitoring.html#gab6b19fe5667ce4ea447d19d5ed88ae7d":[5,38,20],
+"group__API__Perf__Monitoring.html#gaba3d2e0ac27cf891689bd62805656d5f":[5,38,32],
+"group__API__Perf__Monitoring.html#gac0251242696b1b9c977ce9c73930cbd9":[5,38,9],
+"group__API__Perf__Monitoring.html#gad3a66e71b5a5e3b2e44df2d7326ae73b":[5,38,2],
 "group__API__Perf__Monitoring.html#gad3e6ba0b643d9bd1a3e8920bf0b3dbea":[5,38,17],
 "group__API__Perf__Monitoring.html#gadee4d7d4b66e61fed1cf539b6a4411a8":[5,38,5],
 "group__API__Perf__Monitoring.html#gae9960277a9e4f22f8000ba34aa6afc42":[5,38,19],
@@ -245,9 +249,5 @@ var NAVTREEINDEX7 =
 "group__API__SC__Hypervisor.html#a5245eb597997de0cafafe19ece066cdc":[5,47,2,5],
 "group__API__SC__Hypervisor.html#a577d9798523bb202f0867ea1a818c88f":[5,47,1,2],
 "group__API__SC__Hypervisor.html#a6f4bdf0b6ff0c2ab8d4150e65f2b36e5":[5,47,2,3],
-"group__API__SC__Hypervisor.html#a79204440a1911eb6411fa6b8d803e08b":[5,47,1,1],
-"group__API__SC__Hypervisor.html#a79c6a87b792c849cc6c388dbf17d2d49":[5,47,1,4],
-"group__API__SC__Hypervisor.html#a829c79920efa453ee18491e8a85c1ff6":[5,47,3,3],
-"group__API__SC__Hypervisor.html#a838a86b485c9091ab11ea78bfbd12edd":[5,47,2,2],
-"group__API__SC__Hypervisor.html#a9a8cebea8354bedd492764a53037f000":[5,47,2,7]
+"group__API__SC__Hypervisor.html#a79204440a1911eb6411fa6b8d803e08b":[5,47,1,1]
 };
