@@ -1,5 +1,9 @@
 var NAVTREEINDEX9 =
 {
+"group__API__Standard__Memory__Library.html#ga1456598a362e4ee275247bd1a1d4327b":[5,44,22],
+"group__API__Standard__Memory__Library.html#ga18cb9a696ddb392c6874939c8cffd495":[5,44,20],
+"group__API__Standard__Memory__Library.html#ga2abe959e39acfb75c7c0652706dfe84c":[5,44,0],
+"group__API__Standard__Memory__Library.html#ga3506e4b5ab7a605e25968883ded27d64":[5,44,17],
 "group__API__Standard__Memory__Library.html#ga49603eaea3b05e8ced9ba1bd873070c3":[5,44,10],
 "group__API__Standard__Memory__Library.html#ga4c38ddeaf0bba0226f8a5c2c83cf7ab7":[5,44,27],
 "group__API__Standard__Memory__Library.html#ga4e9089680daf0b2d7f26e4657ffe9f48":[5,44,8],
@@ -133,14 +137,14 @@ var NAVTREEINDEX9 =
 "group__API__Toolbox.html":[5,35],
 "group__API__Toolbox.html#ga057b12b615ce9e8a1fe7b5e10d9a5c2e":[5,35,10],
 "group__API__Toolbox.html#ga05ac0dda104331f57d85823a4f9318ce":[5,35,12],
-"group__API__Toolbox.html#ga07b2628bd6680fe49d92c7f816d7ce53":[5,35,21],
+"group__API__Toolbox.html#ga07b2628bd6680fe49d92c7f816d7ce53":[5,35,22],
 "group__API__Toolbox.html#ga10dac0e97a9c6bcc9ae042e067c508ae":[5,35,14],
-"group__API__Toolbox.html#ga1b41d799a04a1d6483e982ffb2f74432":[5,35,19],
+"group__API__Toolbox.html#ga1b41d799a04a1d6483e982ffb2f74432":[5,35,20],
 "group__API__Toolbox.html#ga214c60ee1b6cbc27ab08ba6f339ef8e5":[5,35,8],
 "group__API__Toolbox.html#ga230129f89ca986b143c6b059a9229fb7":[5,35,4],
 "group__API__Toolbox.html#ga23742c6fca8b5386e1f3e3f7bbf3a692":[5,35,1],
-"group__API__Toolbox.html#ga3a4d1fb56668323d4f44c18f6a6dfb3f":[5,35,16],
-"group__API__Toolbox.html#ga4268950ebf63c0f1dabcfd0cd8808067":[5,35,17],
+"group__API__Toolbox.html#ga3a4d1fb56668323d4f44c18f6a6dfb3f":[5,35,17],
+"group__API__Toolbox.html#ga4268950ebf63c0f1dabcfd0cd8808067":[5,35,18],
 "group__API__Toolbox.html#ga4456c2db2cc8df7c98d62ecc21b2bd1d":[5,35,2],
 "group__API__Toolbox.html#ga4fc771a29d7dc0e826da42777edbcf15":[5,35,0],
 "group__API__Toolbox.html#ga71e28fc2a0a5267bc7edc0909d9d5117":[5,35,9],
@@ -148,9 +152,10 @@ var NAVTREEINDEX9 =
 "group__API__Toolbox.html#ga7df091d95d10b854c16cd1cd65cf7508":[5,35,6],
 "group__API__Toolbox.html#ga9804db3e8ffb845492154f63e7d6ae95":[5,35,7],
 "group__API__Toolbox.html#ga9e7c20a6cdce868976a0046206b104e6":[5,35,3],
-"group__API__Toolbox.html#gaa3503ea5efd00806a0f9234f033e6ea1":[5,35,18],
-"group__API__Toolbox.html#gaa5363993d4f519517316ccf9dc47a7bb":[5,35,20],
-"group__API__Toolbox.html#gabb6941113e19ee4045a014943cd62aae":[5,35,15],
+"group__API__Toolbox.html#gaa3503ea5efd00806a0f9234f033e6ea1":[5,35,19],
+"group__API__Toolbox.html#gaa5363993d4f519517316ccf9dc47a7bb":[5,35,21],
+"group__API__Toolbox.html#gabb6941113e19ee4045a014943cd62aae":[5,35,16],
+"group__API__Toolbox.html#gad3ac8d7f5a35aa9c65dcca9915f9a750":[5,35,15],
 "group__API__Toolbox.html#gae07407908792f54312150228d70dbece":[5,35,5],
 "group__API__Toolbox.html#gae8c513ecd1a5bd87a7bdd71260c49ffc":[5,35,11],
 "group__API__Transactions.html":[5,7],
@@ -244,10 +249,5 @@ var NAVTREEINDEX9 =
 "group__API__Workers.html#gae35a841f996b8758f3d0ce2ac2d066a5":[5,18,30],
 "group__API__Workers.html#gae5eabb8523f44bc9ac81031e05f99f66":[5,18,44],
 "group__API__Workers.html#gae6166f338640d033b740f5c8008b851b":[5,18,28],
-"group__API__Workers.html#gaec386585a6952f9c7fb47621844fbb39":[5,18,20],
-"group__API__Workers.html#gaf48e8da13c523a7a9f2530349ddda29e":[5,18,56],
-"group__API__Workers.html#gafc5f2fe263ec932eaf48ab0d313bc322":[5,18,42],
-"group__API__Workers.html#gafcf67f47d1addfbe6ca143f04065b00c":[5,18,48],
-"group__API__Workers.html#gga173d616aefe98c33a47a847fd2fca37da26ced4e9dfc43343f0b442bb465218a9":[5,18,9,1],
-"group__API__Workers.html#gga173d616aefe98c33a47a847fd2fca37da5e57c05c04fb13b5383006cfb7719bf5":[5,18,9,4]
+"group__API__Workers.html#gaec386585a6952f9c7fb47621844fbb39":[5,18,20]
 };
