@@ -1,5 +1,10 @@
 var NAVTREEINDEX10 =
 {
+"group__API__Workers.html#ga21213e018976d3876c85d3ca9ac1dff9":[10,18,31],
+"group__API__Workers.html#ga2b75b2600f85996e943ece2631971c62":[10,18,13],
+"group__API__Workers.html#ga2c930d982bacf4bf4dce015ab2d61123":[10,18,66],
+"group__API__Workers.html#ga35c8908fd60c0407901872b25a8a88da":[10,18,68],
+"group__API__Workers.html#ga389142e108345483dc8c0bf07465263c":[10,18,49],
 "group__API__Workers.html#ga38c0b1858730fec2211991147a964910":[10,18,69],
 "group__API__Workers.html#ga39b7e2b82022313535c7b0015c2a0176":[10,18,45],
 "group__API__Workers.html#ga3a6a9eddecb3e97b3c37e151003ea7c2":[10,18,32],
@@ -195,8 +200,8 @@ var NAVTREEINDEX10 =
 "interfacefstarpu__mod_1_1fstarpu__cuda__get__local__stream.html":[11,0,0,56],
 "interfacefstarpu__mod_1_1fstarpu__cuda__worker__get__count.html":[12,0,0,57],
 "interfacefstarpu__mod_1_1fstarpu__cuda__worker__get__count.html":[11,0,0,57],
-"interfacefstarpu__mod_1_1fstarpu__data__acquire.html":[11,0,0,58],
 "interfacefstarpu__mod_1_1fstarpu__data__acquire.html":[12,0,0,58],
+"interfacefstarpu__mod_1_1fstarpu__data__acquire.html":[11,0,0,58],
 "interfacefstarpu__mod_1_1fstarpu__data__advise__as__important.html":[12,0,0,59],
 "interfacefstarpu__mod_1_1fstarpu__data__advise__as__important.html":[11,0,0,59],
 "interfacefstarpu__mod_1_1fstarpu__data__assign__arbiter.html":[11,0,0,60],
@@ -209,8 +214,8 @@ var NAVTREEINDEX10 =
 "interfacefstarpu__mod_1_1fstarpu__data__descr__alloc.html":[11,0,0,63],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__array__alloc.html":[12,0,0,64],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__array__alloc.html":[11,0,0,64],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__array__free.html":[11,0,0,65],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__array__free.html":[12,0,0,65],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__array__free.html":[11,0,0,65],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__array__set.html":[11,0,0,66],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__array__set.html":[12,0,0,66],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__set.html":[11,0,0,67],
@@ -237,17 +242,12 @@ var NAVTREEINDEX10 =
 "interfacefstarpu__mod_1_1fstarpu__data__filter__set__nchildren.html":[12,0,0,77],
 "interfacefstarpu__mod_1_1fstarpu__data__get__child.html":[11,0,0,78],
 "interfacefstarpu__mod_1_1fstarpu__data__get__child.html":[12,0,0,78],
-"interfacefstarpu__mod_1_1fstarpu__data__get__local__ptr.html":[11,0,0,79],
 "interfacefstarpu__mod_1_1fstarpu__data__get__local__ptr.html":[12,0,0,79],
-"interfacefstarpu__mod_1_1fstarpu__data__get__nb__children.html":[11,0,0,80],
+"interfacefstarpu__mod_1_1fstarpu__data__get__local__ptr.html":[11,0,0,79],
 "interfacefstarpu__mod_1_1fstarpu__data__get__nb__children.html":[12,0,0,80],
+"interfacefstarpu__mod_1_1fstarpu__data__get__nb__children.html":[11,0,0,80],
 "interfacefstarpu__mod_1_1fstarpu__data__get__sub__data.html":[11,0,0,81],
 "interfacefstarpu__mod_1_1fstarpu__data__get__sub__data.html":[12,0,0,81],
 "interfacefstarpu__mod_1_1fstarpu__data__handle__array__alloc.html":[11,0,0,82],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__array__alloc.html":[12,0,0,82],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__array__free.html":[11,0,0,83],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__array__free.html":[12,0,0,83],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__array__set.html":[12,0,0,84],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__array__set.html":[11,0,0,84],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__to__pointer.html":[12,0,0,85]
+"interfacefstarpu__mod_1_1fstarpu__data__handle__array__alloc.html":[12,0,0,82]
 };
