@@ -1,5 +1,8 @@
 var NAVTREEINDEX4 =
 {
+"group__API__FFT__Support.html#ga642104c645445688177f1a44afeeefb0":[10,1,1],
+"group__API__FFT__Support.html#ga8e37e0bd1edc887cf456dcf7d95b86c4":[10,1,3],
+"group__API__FFT__Support.html#gabf7989748571ab9155a865a19002d1fa":[10,1,0],
 "group__API__FFT__Support.html#gabff378384df24d2c2ea296397b600569":[10,1,4],
 "group__API__FFT__Support.html#gae73ea67d1d7df63938661c7a1105800a":[10,1,5],
 "group__API__FFT__Support.html#gaf263d43c43927007819edf069cc8c93b":[10,1,2],
@@ -15,6 +18,7 @@ var NAVTREEINDEX4 =
 "group__API__FxT__Support.html#ad989ef1acebea5296285ba1543b9b8d3":[10,34,2,2],
 "group__API__FxT__Support.html#ae8825a6b5c62dd05bdc8508c9f0bf09c":[10,34,1,0],
 "group__API__FxT__Support.html#ae8b5695146698ba1d5aef8c9237b5272":[10,34,2,3],
+"group__API__FxT__Support.html#ga044878f9b946fd4c265ba6e725e2468c":[10,34,9],
 "group__API__FxT__Support.html#ga2e55ad671e94b6161755717b1c8b44c1":[10,34,7],
 "group__API__FxT__Support.html#ga52a3e1a95689315f0b789a3325ec2a90":[10,34,5],
 "group__API__FxT__Support.html#ga5793bf5c8fc0bedf76d18a5fa38593df":[10,34,4],
@@ -245,9 +249,5 @@ var NAVTREEINDEX4 =
 "group__API__Interop__Support.html#gaaa53e570e6563d20aff14951063f526e":[10,50,14],
 "group__API__Interop__Support.html#gaaab770063ad7206e46710218a6c362cb":[10,50,15],
 "group__API__Interop__Support.html#gaac966eeb8468e3cdab82264383773293":[10,50,18],
-"group__API__Interop__Support.html#gaaf29591aca9820e00a4a344175561ec0":[10,50,5],
-"group__API__Interop__Support.html#gaba890f505d0373ec0da5ca4a87e23d3c":[10,50,43],
-"group__API__Interop__Support.html#gabac59e33ab90205796c3c32088c9dca7":[10,50,27],
-"group__API__Interop__Support.html#gabfa1459181ebb9b71f185d42d2414d91":[10,50,44],
-"group__API__Interop__Support.html#gad05a3754e71e0dfb86d2ae5633287e7a":[10,50,52]
+"group__API__Interop__Support.html#gaaf29591aca9820e00a4a344175561ec0":[10,50,5]
 };
