@@ -1,5 +1,9 @@
 var NAVTREEINDEX10 =
 {
+"group__API__Threads.html#ga4f00fbbe6f909998ecec7c3cc3715e21":[25,3,55],
+"group__API__Threads.html#ga5bc60d93e1403658c30c998d1b6edd11":[25,3,52],
+"group__API__Threads.html#ga5e53025adc42966a97d616304bd654bd":[25,3,6],
+"group__API__Threads.html#ga5ec606cedc543ee35f3c7dc8a8e2505b":[25,3,64],
 "group__API__Threads.html#ga629152a86070cd58811fa17506f7995e":[25,3,12],
 "group__API__Threads.html#ga654b486b4161002221a75cc619eabe48":[25,3,30],
 "group__API__Threads.html#ga670ae411d7536934d784c88c6d11177c":[25,3,28],
@@ -43,14 +47,14 @@ var NAVTREEINDEX10 =
 "group__API__Toolbox.html":[25,35],
 "group__API__Toolbox.html#ga057b12b615ce9e8a1fe7b5e10d9a5c2e":[25,35,10],
 "group__API__Toolbox.html#ga05ac0dda104331f57d85823a4f9318ce":[25,35,12],
-"group__API__Toolbox.html#ga07b2628bd6680fe49d92c7f816d7ce53":[25,35,21],
+"group__API__Toolbox.html#ga07b2628bd6680fe49d92c7f816d7ce53":[25,35,22],
 "group__API__Toolbox.html#ga10dac0e97a9c6bcc9ae042e067c508ae":[25,35,14],
-"group__API__Toolbox.html#ga1b41d799a04a1d6483e982ffb2f74432":[25,35,19],
+"group__API__Toolbox.html#ga1b41d799a04a1d6483e982ffb2f74432":[25,35,20],
 "group__API__Toolbox.html#ga214c60ee1b6cbc27ab08ba6f339ef8e5":[25,35,8],
 "group__API__Toolbox.html#ga230129f89ca986b143c6b059a9229fb7":[25,35,4],
 "group__API__Toolbox.html#ga23742c6fca8b5386e1f3e3f7bbf3a692":[25,35,1],
-"group__API__Toolbox.html#ga3a4d1fb56668323d4f44c18f6a6dfb3f":[25,35,16],
-"group__API__Toolbox.html#ga4268950ebf63c0f1dabcfd0cd8808067":[25,35,17],
+"group__API__Toolbox.html#ga3a4d1fb56668323d4f44c18f6a6dfb3f":[25,35,17],
+"group__API__Toolbox.html#ga4268950ebf63c0f1dabcfd0cd8808067":[25,35,18],
 "group__API__Toolbox.html#ga4456c2db2cc8df7c98d62ecc21b2bd1d":[25,35,2],
 "group__API__Toolbox.html#ga4fc771a29d7dc0e826da42777edbcf15":[25,35,0],
 "group__API__Toolbox.html#ga71e28fc2a0a5267bc7edc0909d9d5117":[25,35,9],
@@ -58,9 +62,10 @@ var NAVTREEINDEX10 =
 "group__API__Toolbox.html#ga7df091d95d10b854c16cd1cd65cf7508":[25,35,6],
 "group__API__Toolbox.html#ga9804db3e8ffb845492154f63e7d6ae95":[25,35,7],
 "group__API__Toolbox.html#ga9e7c20a6cdce868976a0046206b104e6":[25,35,3],
-"group__API__Toolbox.html#gaa3503ea5efd00806a0f9234f033e6ea1":[25,35,18],
-"group__API__Toolbox.html#gaa5363993d4f519517316ccf9dc47a7bb":[25,35,20],
-"group__API__Toolbox.html#gabb6941113e19ee4045a014943cd62aae":[25,35,15],
+"group__API__Toolbox.html#gaa3503ea5efd00806a0f9234f033e6ea1":[25,35,19],
+"group__API__Toolbox.html#gaa5363993d4f519517316ccf9dc47a7bb":[25,35,21],
+"group__API__Toolbox.html#gabb6941113e19ee4045a014943cd62aae":[25,35,16],
+"group__API__Toolbox.html#gad3ac8d7f5a35aa9c65dcca9915f9a750":[25,35,15],
 "group__API__Toolbox.html#gae07407908792f54312150228d70dbece":[25,35,5],
 "group__API__Toolbox.html#gae8c513ecd1a5bd87a7bdd71260c49ffc":[25,35,11],
 "group__API__Transactions.html":[25,7],
@@ -184,70 +189,65 @@ var NAVTREEINDEX10 =
 "index.html":[],
 "interfacefstarpu__mod_1_1fstarpu__arbiter__create.html":[26,0,0,0],
 "interfacefstarpu__mod_1_1fstarpu__arbiter__create.html":[27,0,0,0],
-"interfacefstarpu__mod_1_1fstarpu__arbiter__destroy.html":[26,0,0,1],
 "interfacefstarpu__mod_1_1fstarpu__arbiter__destroy.html":[27,0,0,1],
-"interfacefstarpu__mod_1_1fstarpu__asynchronous__copy__disabled.html":[26,0,0,2],
+"interfacefstarpu__mod_1_1fstarpu__arbiter__destroy.html":[26,0,0,1],
 "interfacefstarpu__mod_1_1fstarpu__asynchronous__copy__disabled.html":[27,0,0,2],
+"interfacefstarpu__mod_1_1fstarpu__asynchronous__copy__disabled.html":[26,0,0,2],
 "interfacefstarpu__mod_1_1fstarpu__asynchronous__cuda__copy__disabled.html":[27,0,0,3],
 "interfacefstarpu__mod_1_1fstarpu__asynchronous__cuda__copy__disabled.html":[26,0,0,3],
 "interfacefstarpu__mod_1_1fstarpu__asynchronous__opencl__copy__disabled.html":[27,0,0,4],
 "interfacefstarpu__mod_1_1fstarpu__asynchronous__opencl__copy__disabled.html":[26,0,0,4],
-"interfacefstarpu__mod_1_1fstarpu__block__data__register.html":[27,0,0,5],
 "interfacefstarpu__mod_1_1fstarpu__block__data__register.html":[26,0,0,5],
+"interfacefstarpu__mod_1_1fstarpu__block__data__register.html":[27,0,0,5],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__block.html":[26,0,0,6],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__block.html":[27,0,0,6],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__block__shadow.html":[26,0,0,7],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__block__shadow.html":[27,0,0,7],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block.html":[26,0,0,8],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block.html":[27,0,0,8],
-"interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block__shadow.html":[26,0,0,9],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block__shadow.html":[27,0,0,9],
-"interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block.html":[26,0,0,10],
+"interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block__shadow.html":[26,0,0,9],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block.html":[27,0,0,10],
-"interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block__shadow.html":[26,0,0,11],
+"interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block.html":[26,0,0,10],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block__shadow.html":[27,0,0,11],
-"interfacefstarpu__mod_1_1fstarpu__block__get__ldy.html":[26,0,0,12],
+"interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block__shadow.html":[26,0,0,11],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ldy.html":[27,0,0,12],
-"interfacefstarpu__mod_1_1fstarpu__block__get__ldz.html":[27,0,0,13],
+"interfacefstarpu__mod_1_1fstarpu__block__get__ldy.html":[26,0,0,12],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ldz.html":[26,0,0,13],
-"interfacefstarpu__mod_1_1fstarpu__block__get__nx.html":[27,0,0,14],
+"interfacefstarpu__mod_1_1fstarpu__block__get__ldz.html":[27,0,0,13],
 "interfacefstarpu__mod_1_1fstarpu__block__get__nx.html":[26,0,0,14],
-"interfacefstarpu__mod_1_1fstarpu__block__get__ny.html":[27,0,0,15],
+"interfacefstarpu__mod_1_1fstarpu__block__get__nx.html":[27,0,0,14],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ny.html":[26,0,0,15],
-"interfacefstarpu__mod_1_1fstarpu__block__get__nz.html":[27,0,0,16],
+"interfacefstarpu__mod_1_1fstarpu__block__get__ny.html":[27,0,0,15],
 "interfacefstarpu__mod_1_1fstarpu__block__get__nz.html":[26,0,0,16],
+"interfacefstarpu__mod_1_1fstarpu__block__get__nz.html":[27,0,0,16],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ptr.html":[26,0,0,17],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ptr.html":[27,0,0,17],
 "interfacefstarpu__mod_1_1fstarpu__block__ptr__register.html":[26,0,0,18],
 "interfacefstarpu__mod_1_1fstarpu__block__ptr__register.html":[27,0,0,18],
-"interfacefstarpu__mod_1_1fstarpu__codelet__add__buffer.html":[26,0,0,19],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__buffer.html":[27,0,0,19],
-"interfacefstarpu__mod_1_1fstarpu__codelet__add__cpu__func.html":[26,0,0,20],
+"interfacefstarpu__mod_1_1fstarpu__codelet__add__buffer.html":[26,0,0,19],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__cpu__func.html":[27,0,0,20],
-"interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__flags.html":[26,0,0,21],
+"interfacefstarpu__mod_1_1fstarpu__codelet__add__cpu__func.html":[26,0,0,20],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__flags.html":[27,0,0,21],
-"interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__func.html":[26,0,0,22],
+"interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__flags.html":[26,0,0,21],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__func.html":[27,0,0,22],
+"interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__func.html":[26,0,0,22],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__flags.html":[26,0,0,23],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__flags.html":[27,0,0,23],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__func.html":[27,0,0,24],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__func.html":[26,0,0,24],
 "interfacefstarpu__mod_1_1fstarpu__codelet__allocate.html":[26,0,0,25],
 "interfacefstarpu__mod_1_1fstarpu__codelet__allocate.html":[27,0,0,25],
-"interfacefstarpu__mod_1_1fstarpu__codelet__display__stats.html":[26,0,0,26],
 "interfacefstarpu__mod_1_1fstarpu__codelet__display__stats.html":[27,0,0,26],
-"interfacefstarpu__mod_1_1fstarpu__codelet__free.html":[26,0,0,27],
+"interfacefstarpu__mod_1_1fstarpu__codelet__display__stats.html":[26,0,0,26],
 "interfacefstarpu__mod_1_1fstarpu__codelet__free.html":[27,0,0,27],
-"interfacefstarpu__mod_1_1fstarpu__codelet__init.html":[26,0,0,28],
+"interfacefstarpu__mod_1_1fstarpu__codelet__free.html":[26,0,0,27],
 "interfacefstarpu__mod_1_1fstarpu__codelet__init.html":[27,0,0,28],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__color.html":[26,0,0,29],
+"interfacefstarpu__mod_1_1fstarpu__codelet__init.html":[26,0,0,28],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__color.html":[27,0,0,29],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__energy__model.html":[26,0,0,30],
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__color.html":[26,0,0,29],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__energy__model.html":[27,0,0,30],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__flags.html":[26,0,0,31],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__flags.html":[27,0,0,31],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__max__parallelism.html":[26,0,0,32],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__max__parallelism.html":[27,0,0,32],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__model.html":[27,0,0,33],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__model.html":[26,0,0,33]
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__energy__model.html":[26,0,0,30],
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__flags.html":[26,0,0,31]
 };
