@@ -1,5 +1,10 @@
 var NAVTREEINDEX6 =
 {
+"group__API__Modularized__Scheduler.html#structstarpu__sched__component__perfmodel__select__data":[5,22,6],
+"group__API__Modularized__Scheduler.html#structstarpu__sched__component__prio__data":[5,22,3],
+"group__API__Modularized__Scheduler.html#structstarpu__sched__component__specs":[5,22,7],
+"group__API__Modularized__Scheduler.html#structstarpu__sched__tree":[5,22,1],
+"group__API__OpenCL__Extensions.html":[5,15],
 "group__API__OpenCL__Extensions.html#a685357d9709ece920bf269a917ed8297":[5,15,0,0],
 "group__API__OpenCL__Extensions.html#ga002e85a0f6bcd087df54287de5ae5e07":[5,15,30],
 "group__API__OpenCL__Extensions.html#ga03f34ac98495afc5d0f268e366f80598":[5,15,15],
@@ -244,10 +249,5 @@ var NAVTREEINDEX6 =
 "group__API__Parallel__Worker.html#gga9adce159e1660dcd3ef111816b75b04da6ec1cddc254911b1c4c6bc4103b615e5":[5,37,28,0],
 "group__API__Parallel__Worker.html#gga9adce159e1660dcd3ef111816b75b04daea3cad2ef001f27c6717b38e9738e11f":[5,37,28,1],
 "group__API__Perf__Monitoring.html":[5,38],
-"group__API__Perf__Monitoring.html#ga000af6e254ec5a3e95868f50d354f693":[5,38,4],
-"group__API__Perf__Monitoring.html#ga0a9c21a6b765059a5f5f72ab10dd99fa":[5,38,12],
-"group__API__Perf__Monitoring.html#ga0d09d776a8250c995d3e40d77bb10628":[5,38,33],
-"group__API__Perf__Monitoring.html#ga13f8e7f707f5bab7bc4f45291effd109":[5,38,15],
-"group__API__Perf__Monitoring.html#ga15b96ecd4161e8abdea440ad89262766":[5,38,24],
-"group__API__Perf__Monitoring.html#ga1d3b734cccfcb02c47baa5412acf0877":[5,38,1]
+"group__API__Perf__Monitoring.html#ga000af6e254ec5a3e95868f50d354f693":[5,38,4]
 };
