@@ -1,5 +1,10 @@
 var NAVTREEINDEX8 =
 {
+"group__API__Profiling__Tool.html#structstarpu__prof__tool__info":[5,41,0],
+"group__API__Profiling__Tool.html#unionstarpu__prof__tool__event__info":[5,41,1],
+"group__API__Random__Functions.html":[5,42],
+"group__API__Running__Drivers.html":[5,32],
+"group__API__Running__Drivers.html#a08415dd427f53b10ce4176ad77fade39":[5,32,0,1],
 "group__API__Running__Drivers.html#a50af396b52e8c54e4e3b23803105fc0e":[5,32,0,0],
 "group__API__Running__Drivers.html#ga119a52234aebe7fef5da42f9d3989402":[5,32,2],
 "group__API__Running__Drivers.html#ga497d48a24107dfebf6ef3ad40d4a6df8":[5,32,4],
@@ -244,10 +249,5 @@ var NAVTREEINDEX8 =
 "group__API__Scheduling__Policy.html#ga706830b50d163715c28d2fb19abd13bd":[5,24,16],
 "group__API__Scheduling__Policy.html#ga7cfeacbeb8978b05754da35133eeba87":[5,24,26],
 "group__API__Scheduling__Policy.html#ga7f9281edd60ddfaeded3c920a77edbf7":[5,24,46],
-"group__API__Scheduling__Policy.html#ga8004f14208fd9b29f36440dc11ca765b":[5,24,25],
-"group__API__Scheduling__Policy.html#ga87e2aacf5892951d5333a3421e90f278":[5,24,33],
-"group__API__Scheduling__Policy.html#ga8e58ffd062043cf25b47c081b7f6ba88":[5,24,47],
-"group__API__Scheduling__Policy.html#ga8eb834f05df5337dcd8c96f6a74cd1f1":[5,24,41],
-"group__API__Scheduling__Policy.html#ga9424eb90a56d08f804d85be6557ddf66":[5,24,45],
-"group__API__Scheduling__Policy.html#ga94edfd4a02666d8c1b8c506423586426":[5,24,19]
+"group__API__Scheduling__Policy.html#ga8004f14208fd9b29f36440dc11ca765b":[5,24,25]
 };
