@@ -1,5 +1,7 @@
 var NAVTREEINDEX1 =
 {
+"group__API__Codelet__And__Tasks.html#ga35b5e2238449047ac6beb8ef591c6a41":[5,6,73],
+"group__API__Codelet__And__Tasks.html#ga3c2546614b19e43aad2bed0d935b38b4":[5,6,18],
 "group__API__Codelet__And__Tasks.html#ga3c6c4dd317df02d7021e23ab6b14e3e2":[5,6,60],
 "group__API__Codelet__And__Tasks.html#ga3f27bbe96afa84eca01264746837d692":[5,6,30],
 "group__API__Codelet__And__Tasks.html#ga40d2902534fe61a0fb2ddad227619df6":[5,6,90],
@@ -247,7 +249,5 @@ var NAVTREEINDEX1 =
 "group__API__Data__Interfaces.html#ga057157e8f437d111d74b7167386f9e9a":[5,9,169],
 "group__API__Data__Interfaces.html#ga07eb2ecc8ee04523993aeb0be19a8878":[5,9,52],
 "group__API__Data__Interfaces.html#ga088d9e8e6e18e77ed13c299e836c3aeb":[5,9,184],
-"group__API__Data__Interfaces.html#ga08bed7d1e9b7cb2b2b76932eb9c33353":[5,9,186],
-"group__API__Data__Interfaces.html#ga0b6869745c464525b25a0757d112c318":[5,9,105],
-"group__API__Data__Interfaces.html#ga0cea5d347fdd4b5a44ecc9fe0295898c":[5,9,59]
+"group__API__Data__Interfaces.html#ga08bed7d1e9b7cb2b2b76932eb9c33353":[5,9,186]
 };
