@@ -1,5 +1,10 @@
 var NAVTREEINDEX10 =
 {
+"group__API__Workers.html#gga173d616aefe98c33a47a847fd2fca37dadc9efedf9b6e4e6ce71d8522f6c1206f":[5,18,9,7],
+"group__API__Workers.html#gga173d616aefe98c33a47a847fd2fca37daf5a63ea6a5480c1a6bcf65db1a4c8761":[5,18,9,5],
+"group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1a0f41ef0eff3429abe8480b285c8e37d9":[5,18,8,8],
+"group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1a25ef72894680c188a842f2cefebeb673":[5,18,8,7],
+"group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1a30be863a2bfc1c5b98c9f2ccdf62394a":[5,18,8,6],
 "group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1a3bb8e78a9fffd443b2e87d648a1c7531":[5,18,8,3],
 "group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1a4f0b10cf4c5fb6333b9e3906b81cc5a6":[5,18,8,1],
 "group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1a59908ef1a8ddbae47f0ff0ed704678af":[5,18,8,4],
@@ -11,28 +16,28 @@ var NAVTREEINDEX10 =
 "group__API__Workers.html#gga80b06886ee8a4c0e99b09ab638113af3a574a8ee7f0fc8414cd16767c88481d26":[5,18,10,1],
 "group__API__Workers.html#structstarpu__sched__ctx__iterator":[5,18,0],
 "group__API__Workers.html#structstarpu__worker__collection":[5,18,1],
-"index.html":[],
 "index.html":[0],
+"index.html":[],
 "index.html#ApplicationTaskification":[0,2],
 "index.html#CodeletAndTasks":[0,1,0],
 "index.html#Motivation":[0,0],
 "index.html#ResearchPapers":[0,3],
 "index.html#StarPUDataManagementLibrary":[0,1,1],
 "index.html#StarPUInANutshell":[0,1],
-"interfacefstarpu__mod_1_1fstarpu__arbiter__create.html":[7,0,0,0],
 "interfacefstarpu__mod_1_1fstarpu__arbiter__create.html":[6,0,0,0],
+"interfacefstarpu__mod_1_1fstarpu__arbiter__create.html":[7,0,0,0],
 "interfacefstarpu__mod_1_1fstarpu__arbiter__destroy.html":[7,0,0,1],
 "interfacefstarpu__mod_1_1fstarpu__arbiter__destroy.html":[6,0,0,1],
 "interfacefstarpu__mod_1_1fstarpu__asynchronous__copy__disabled.html":[7,0,0,2],
 "interfacefstarpu__mod_1_1fstarpu__asynchronous__copy__disabled.html":[6,0,0,2],
 "interfacefstarpu__mod_1_1fstarpu__asynchronous__cuda__copy__disabled.html":[7,0,0,3],
 "interfacefstarpu__mod_1_1fstarpu__asynchronous__cuda__copy__disabled.html":[6,0,0,3],
-"interfacefstarpu__mod_1_1fstarpu__asynchronous__opencl__copy__disabled.html":[6,0,0,4],
 "interfacefstarpu__mod_1_1fstarpu__asynchronous__opencl__copy__disabled.html":[7,0,0,4],
-"interfacefstarpu__mod_1_1fstarpu__block__data__register.html":[6,0,0,5],
+"interfacefstarpu__mod_1_1fstarpu__asynchronous__opencl__copy__disabled.html":[6,0,0,4],
 "interfacefstarpu__mod_1_1fstarpu__block__data__register.html":[7,0,0,5],
-"interfacefstarpu__mod_1_1fstarpu__block__filter__block.html":[6,0,0,6],
+"interfacefstarpu__mod_1_1fstarpu__block__data__register.html":[6,0,0,5],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__block.html":[7,0,0,6],
+"interfacefstarpu__mod_1_1fstarpu__block__filter__block.html":[6,0,0,6],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__block__shadow.html":[7,0,0,7],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__block__shadow.html":[6,0,0,7],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block.html":[7,0,0,8],
@@ -49,16 +54,16 @@ var NAVTREEINDEX10 =
 "interfacefstarpu__mod_1_1fstarpu__block__get__ldz.html":[6,0,0,13],
 "interfacefstarpu__mod_1_1fstarpu__block__get__nx.html":[7,0,0,14],
 "interfacefstarpu__mod_1_1fstarpu__block__get__nx.html":[6,0,0,14],
-"interfacefstarpu__mod_1_1fstarpu__block__get__ny.html":[6,0,0,15],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ny.html":[7,0,0,15],
-"interfacefstarpu__mod_1_1fstarpu__block__get__nz.html":[6,0,0,16],
+"interfacefstarpu__mod_1_1fstarpu__block__get__ny.html":[6,0,0,15],
 "interfacefstarpu__mod_1_1fstarpu__block__get__nz.html":[7,0,0,16],
+"interfacefstarpu__mod_1_1fstarpu__block__get__nz.html":[6,0,0,16],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ptr.html":[6,0,0,17],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ptr.html":[7,0,0,17],
 "interfacefstarpu__mod_1_1fstarpu__block__ptr__register.html":[6,0,0,18],
 "interfacefstarpu__mod_1_1fstarpu__block__ptr__register.html":[7,0,0,18],
-"interfacefstarpu__mod_1_1fstarpu__codelet__add__buffer.html":[7,0,0,19],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__buffer.html":[6,0,0,19],
+"interfacefstarpu__mod_1_1fstarpu__codelet__add__buffer.html":[7,0,0,19],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__cpu__func.html":[6,0,0,20],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__cpu__func.html":[7,0,0,20],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__flags.html":[6,0,0,21],
@@ -67,20 +72,20 @@ var NAVTREEINDEX10 =
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__func.html":[7,0,0,22],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__flags.html":[7,0,0,23],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__flags.html":[6,0,0,23],
-"interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__func.html":[7,0,0,24],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__func.html":[6,0,0,24],
+"interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__func.html":[7,0,0,24],
 "interfacefstarpu__mod_1_1fstarpu__codelet__allocate.html":[6,0,0,25],
 "interfacefstarpu__mod_1_1fstarpu__codelet__allocate.html":[7,0,0,25],
 "interfacefstarpu__mod_1_1fstarpu__codelet__display__stats.html":[6,0,0,26],
 "interfacefstarpu__mod_1_1fstarpu__codelet__display__stats.html":[7,0,0,26],
-"interfacefstarpu__mod_1_1fstarpu__codelet__free.html":[6,0,0,27],
 "interfacefstarpu__mod_1_1fstarpu__codelet__free.html":[7,0,0,27],
-"interfacefstarpu__mod_1_1fstarpu__codelet__init.html":[7,0,0,28],
+"interfacefstarpu__mod_1_1fstarpu__codelet__free.html":[6,0,0,27],
 "interfacefstarpu__mod_1_1fstarpu__codelet__init.html":[6,0,0,28],
+"interfacefstarpu__mod_1_1fstarpu__codelet__init.html":[7,0,0,28],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__color.html":[7,0,0,29],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__color.html":[6,0,0,29],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__energy__model.html":[6,0,0,30],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__energy__model.html":[7,0,0,30],
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__energy__model.html":[6,0,0,30],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__flags.html":[6,0,0,31],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__flags.html":[7,0,0,31],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__max__parallelism.html":[6,0,0,32],
@@ -89,24 +94,24 @@ var NAVTREEINDEX10 =
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__model.html":[7,0,0,33],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__name.html":[7,0,0,34],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__name.html":[6,0,0,34],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__nbuffers.html":[6,0,0,35],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__nbuffers.html":[7,0,0,35],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__type.html":[6,0,0,36],
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__nbuffers.html":[6,0,0,35],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__type.html":[7,0,0,36],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__variable__nbuffers.html":[7,0,0,37],
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__type.html":[6,0,0,36],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__variable__nbuffers.html":[6,0,0,37],
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__variable__nbuffers.html":[7,0,0,37],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__where.html":[7,0,0,38],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__where.html":[6,0,0,38],
-"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__count.html":[7,0,0,39],
 "interfacefstarpu__mod_1_1fstarpu__combined__worker__get__count.html":[6,0,0,39],
-"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__id.html":[7,0,0,40],
+"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__count.html":[7,0,0,39],
 "interfacefstarpu__mod_1_1fstarpu__combined__worker__get__id.html":[6,0,0,40],
-"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__rank.html":[6,0,0,41],
+"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__id.html":[7,0,0,40],
 "interfacefstarpu__mod_1_1fstarpu__combined__worker__get__rank.html":[7,0,0,41],
-"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__size.html":[7,0,0,42],
+"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__rank.html":[6,0,0,41],
 "interfacefstarpu__mod_1_1fstarpu__combined__worker__get__size.html":[6,0,0,42],
-"interfacefstarpu__mod_1_1fstarpu__conf__allocate.html":[7,0,0,43],
+"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__size.html":[7,0,0,42],
 "interfacefstarpu__mod_1_1fstarpu__conf__allocate.html":[6,0,0,43],
+"interfacefstarpu__mod_1_1fstarpu__conf__allocate.html":[7,0,0,43],
 "interfacefstarpu__mod_1_1fstarpu__conf__free.html":[7,0,0,44],
 "interfacefstarpu__mod_1_1fstarpu__conf__free.html":[6,0,0,44],
 "interfacefstarpu__mod_1_1fstarpu__conf__init.html":[7,0,0,45],
@@ -119,8 +124,8 @@ var NAVTREEINDEX10 =
 "interfacefstarpu__mod_1_1fstarpu__conf__set__ncpu.html":[6,0,0,48],
 "interfacefstarpu__mod_1_1fstarpu__conf__set__ncuda.html":[7,0,0,49],
 "interfacefstarpu__mod_1_1fstarpu__conf__set__ncuda.html":[6,0,0,49],
-"interfacefstarpu__mod_1_1fstarpu__conf__set__nopencl.html":[6,0,0,50],
 "interfacefstarpu__mod_1_1fstarpu__conf__set__nopencl.html":[7,0,0,50],
+"interfacefstarpu__mod_1_1fstarpu__conf__set__nopencl.html":[6,0,0,50],
 "interfacefstarpu__mod_1_1fstarpu__conf__set__sched__policy__name.html":[7,0,0,51],
 "interfacefstarpu__mod_1_1fstarpu__conf__set__sched__policy__name.html":[6,0,0,51],
 "interfacefstarpu__mod_1_1fstarpu__cpu__worker__get__count.html":[7,0,0,52],
@@ -155,8 +160,8 @@ var NAVTREEINDEX10 =
 "interfacefstarpu__mod_1_1fstarpu__data__descr__array__set.html":[7,0,0,66],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__set.html":[6,0,0,67],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__set.html":[7,0,0,67],
-"interfacefstarpu__mod_1_1fstarpu__data__descrg__free.html":[7,0,0,68],
 "interfacefstarpu__mod_1_1fstarpu__data__descrg__free.html":[6,0,0,68],
+"interfacefstarpu__mod_1_1fstarpu__data__descrg__free.html":[7,0,0,68],
 "interfacefstarpu__mod_1_1fstarpu__data__fetch__on__node.html":[7,0,0,69],
 "interfacefstarpu__mod_1_1fstarpu__data__fetch__on__node.html":[6,0,0,69],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__allocate.html":[7,0,0,70],
@@ -175,48 +180,48 @@ var NAVTREEINDEX10 =
 "interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__nchildren__func.html":[6,0,0,76],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__set__nchildren.html":[7,0,0,77],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__set__nchildren.html":[6,0,0,77],
-"interfacefstarpu__mod_1_1fstarpu__data__get__child.html":[6,0,0,78],
 "interfacefstarpu__mod_1_1fstarpu__data__get__child.html":[7,0,0,78],
+"interfacefstarpu__mod_1_1fstarpu__data__get__child.html":[6,0,0,78],
 "interfacefstarpu__mod_1_1fstarpu__data__get__local__ptr.html":[6,0,0,79],
 "interfacefstarpu__mod_1_1fstarpu__data__get__local__ptr.html":[7,0,0,79],
-"interfacefstarpu__mod_1_1fstarpu__data__get__nb__children.html":[7,0,0,80],
 "interfacefstarpu__mod_1_1fstarpu__data__get__nb__children.html":[6,0,0,80],
+"interfacefstarpu__mod_1_1fstarpu__data__get__nb__children.html":[7,0,0,80],
 "interfacefstarpu__mod_1_1fstarpu__data__get__sub__data.html":[7,0,0,81],
 "interfacefstarpu__mod_1_1fstarpu__data__get__sub__data.html":[6,0,0,81],
 "interfacefstarpu__mod_1_1fstarpu__data__handle__array__alloc.html":[7,0,0,82],
 "interfacefstarpu__mod_1_1fstarpu__data__handle__array__alloc.html":[6,0,0,82],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__array__free.html":[6,0,0,83],
 "interfacefstarpu__mod_1_1fstarpu__data__handle__array__free.html":[7,0,0,83],
+"interfacefstarpu__mod_1_1fstarpu__data__handle__array__free.html":[6,0,0,83],
 "interfacefstarpu__mod_1_1fstarpu__data__handle__array__set.html":[7,0,0,84],
 "interfacefstarpu__mod_1_1fstarpu__data__handle__array__set.html":[6,0,0,84],
 "interfacefstarpu__mod_1_1fstarpu__data__handle__to__pointer.html":[7,0,0,85],
 "interfacefstarpu__mod_1_1fstarpu__data__handle__to__pointer.html":[6,0,0,85],
 "interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node.html":[7,0,0,86],
 "interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node.html":[6,0,0,86],
-"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node__prio.html":[6,0,0,87],
 "interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node__prio.html":[7,0,0,87],
-"interfacefstarpu__mod_1_1fstarpu__data__invalidate.html":[6,0,0,88],
+"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node__prio.html":[6,0,0,87],
 "interfacefstarpu__mod_1_1fstarpu__data__invalidate.html":[7,0,0,88],
-"interfacefstarpu__mod_1_1fstarpu__data__invalidate__submit.html":[6,0,0,89],
+"interfacefstarpu__mod_1_1fstarpu__data__invalidate.html":[6,0,0,88],
 "interfacefstarpu__mod_1_1fstarpu__data__invalidate__submit.html":[7,0,0,89],
-"interfacefstarpu__mod_1_1fstarpu__data__is__on__node.html":[7,0,0,90],
+"interfacefstarpu__mod_1_1fstarpu__data__invalidate__submit.html":[6,0,0,89],
 "interfacefstarpu__mod_1_1fstarpu__data__is__on__node.html":[6,0,0,90],
+"interfacefstarpu__mod_1_1fstarpu__data__is__on__node.html":[7,0,0,90],
 "interfacefstarpu__mod_1_1fstarpu__data__map__filters.html":[6,0,0,91],
 "interfacefstarpu__mod_1_1fstarpu__data__map__filters.html":[7,0,0,91],
-"interfacefstarpu__mod_1_1fstarpu__data__partition.html":[6,0,0,92],
 "interfacefstarpu__mod_1_1fstarpu__data__partition.html":[7,0,0,92],
-"interfacefstarpu__mod_1_1fstarpu__data__partition__clean.html":[7,0,0,93],
+"interfacefstarpu__mod_1_1fstarpu__data__partition.html":[6,0,0,92],
 "interfacefstarpu__mod_1_1fstarpu__data__partition__clean.html":[6,0,0,93],
+"interfacefstarpu__mod_1_1fstarpu__data__partition__clean.html":[7,0,0,93],
 "interfacefstarpu__mod_1_1fstarpu__data__partition__plan.html":[7,0,0,94],
 "interfacefstarpu__mod_1_1fstarpu__data__partition__plan.html":[6,0,0,94],
-"interfacefstarpu__mod_1_1fstarpu__data__partition__readonly__submit.html":[6,0,0,95],
 "interfacefstarpu__mod_1_1fstarpu__data__partition__readonly__submit.html":[7,0,0,95],
+"interfacefstarpu__mod_1_1fstarpu__data__partition__readonly__submit.html":[6,0,0,95],
 "interfacefstarpu__mod_1_1fstarpu__data__partition__readwrite__upgrade__submit.html":[7,0,0,96],
 "interfacefstarpu__mod_1_1fstarpu__data__partition__readwrite__upgrade__submit.html":[6,0,0,96],
 "interfacefstarpu__mod_1_1fstarpu__data__partition__submit.html":[7,0,0,97],
 "interfacefstarpu__mod_1_1fstarpu__data__partition__submit.html":[6,0,0,97],
-"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node.html":[7,0,0,98],
 "interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node.html":[6,0,0,98],
+"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node.html":[7,0,0,98],
 "interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node__prio.html":[7,0,0,99],
 "interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node__prio.html":[6,0,0,99],
 "interfacefstarpu__mod_1_1fstarpu__data__register__same.html":[7,0,0,100],
@@ -225,29 +230,24 @@ var NAVTREEINDEX10 =
 "interfacefstarpu__mod_1_1fstarpu__data__release.html":[6,0,0,101],
 "interfacefstarpu__mod_1_1fstarpu__data__release__on__node.html":[6,0,0,102],
 "interfacefstarpu__mod_1_1fstarpu__data__release__on__node.html":[7,0,0,102],
-"interfacefstarpu__mod_1_1fstarpu__data__request__allocation.html":[7,0,0,103],
 "interfacefstarpu__mod_1_1fstarpu__data__request__allocation.html":[6,0,0,103],
+"interfacefstarpu__mod_1_1fstarpu__data__request__allocation.html":[7,0,0,103],
 "interfacefstarpu__mod_1_1fstarpu__data__set__reduction__methods.html":[7,0,0,104],
 "interfacefstarpu__mod_1_1fstarpu__data__set__reduction__methods.html":[6,0,0,104],
-"interfacefstarpu__mod_1_1fstarpu__data__set__reduction__methods__with__args.html":[6,0,0,105],
 "interfacefstarpu__mod_1_1fstarpu__data__set__reduction__methods__with__args.html":[7,0,0,105],
+"interfacefstarpu__mod_1_1fstarpu__data__set__reduction__methods__with__args.html":[6,0,0,105],
 "interfacefstarpu__mod_1_1fstarpu__data__test__if__allocated__on__node.html":[7,0,0,106],
 "interfacefstarpu__mod_1_1fstarpu__data__test__if__allocated__on__node.html":[6,0,0,106],
-"interfacefstarpu__mod_1_1fstarpu__data__unpartition.html":[6,0,0,107],
 "interfacefstarpu__mod_1_1fstarpu__data__unpartition.html":[7,0,0,107],
+"interfacefstarpu__mod_1_1fstarpu__data__unpartition.html":[6,0,0,107],
 "interfacefstarpu__mod_1_1fstarpu__data__unpartition__readonly__submit.html":[6,0,0,108],
 "interfacefstarpu__mod_1_1fstarpu__data__unpartition__readonly__submit.html":[7,0,0,108],
 "interfacefstarpu__mod_1_1fstarpu__data__unpartition__submit.html":[6,0,0,109],
 "interfacefstarpu__mod_1_1fstarpu__data__unpartition__submit.html":[7,0,0,109],
-"interfacefstarpu__mod_1_1fstarpu__data__unregister.html":[6,0,0,110],
 "interfacefstarpu__mod_1_1fstarpu__data__unregister.html":[7,0,0,110],
-"interfacefstarpu__mod_1_1fstarpu__data__unregister__no__coherency.html":[6,0,0,111],
+"interfacefstarpu__mod_1_1fstarpu__data__unregister.html":[6,0,0,110],
 "interfacefstarpu__mod_1_1fstarpu__data__unregister__no__coherency.html":[7,0,0,111],
-"interfacefstarpu__mod_1_1fstarpu__data__unregister__submit.html":[6,0,0,112],
+"interfacefstarpu__mod_1_1fstarpu__data__unregister__no__coherency.html":[6,0,0,111],
 "interfacefstarpu__mod_1_1fstarpu__data__unregister__submit.html":[7,0,0,112],
-"interfacefstarpu__mod_1_1fstarpu__data__wont__use.html":[6,0,0,113],
-"interfacefstarpu__mod_1_1fstarpu__data__wont__use.html":[7,0,0,113],
-"interfacefstarpu__mod_1_1fstarpu__df__alloc__bcsr__filter__canonical__block.html":[7,0,0,114],
-"interfacefstarpu__mod_1_1fstarpu__df__alloc__bcsr__filter__canonical__block.html":[6,0,0,114],
-"interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__block.html":[6,0,0,115]
+"interfacefstarpu__mod_1_1fstarpu__data__unregister__submit.html":[6,0,0,112]
 };
