@@ -1,5 +1,7 @@
 var NAVTREEINDEX3 =
 {
+"group__API__Data__Interfaces.html#gaf972d52af628f82488eeea311eadb4f6":[7,9,191],
+"group__API__Data__Interfaces.html#gafb92c2538dc629d823221c5dc16bd767":[7,9,190],
 "group__API__Data__Interfaces.html#gafd439524218c70b6b4a784fb12824c28":[7,9,215],
 "group__API__Data__Interfaces.html#gafd9d133c4d658b777d9800eba79765b3":[7,9,37],
 "group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357ca1020cba73248160933d8f6c901293437":[7,9,107,5],
@@ -218,6 +220,7 @@ var NAVTREEINDEX3 =
 "group__API__Explicit__Dependencies.html":[7,11],
 "group__API__Explicit__Dependencies.html#ga19e120568fbd21fcac59b93ff324c45f":[7,11,4],
 "group__API__Explicit__Dependencies.html#ga1a93d3d46ea5ade29a3a3ea76b6eb90d":[7,11,8],
+"group__API__Explicit__Dependencies.html#ga2425f146494ef50105f99325f4120522":[7,11,18],
 "group__API__Explicit__Dependencies.html#ga2ab771900cf19e039ade46594dbc5fce":[7,11,3],
 "group__API__Explicit__Dependencies.html#ga53dc7bff09b441ee6a200cae99ca2cb8":[7,11,5],
 "group__API__Explicit__Dependencies.html#ga6d09446c8849f42edeced84c558e6a49":[7,11,17],
@@ -246,8 +249,5 @@ var NAVTREEINDEX3 =
 "group__API__FFT__Support.html#gaf263d43c43927007819edf069cc8c93b":[7,1,2],
 "group__API__Fortran.html":[7,2],
 "group__API__FxT__Support.html":[7,34],
-"group__API__FxT__Support.html#a0354339f996ded0f2c8e4863c38a8cda":[7,34,1,1],
-"group__API__FxT__Support.html#a069e624dee891479cec370e8078b26f5":[7,34,2,0],
-"group__API__FxT__Support.html#a156463ba1f63f97358f8ea039248178e":[7,34,1,3],
-"group__API__FxT__Support.html#a554098d2395577300ee6bd1da3c39f57":[7,34,2,1]
+"group__API__FxT__Support.html#a0354339f996ded0f2c8e4863c38a8cda":[7,34,1,1]
 };
